@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2021 Losant IoT, Inc.
+Copyright (c) 2022 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,10 @@ SOFTWARE.
 # pylint: disable=E0401
 
 import requests
-import collections
+try:
+    from collections.abc import Mapping
+except ImportError:
+    from collections import Mapping
 import sys
 from .application import Application
 from .application_api_token import ApplicationApiToken
@@ -86,6 +89,8 @@ from .flows import Flows
 from .instance import Instance
 from .instance_api_token import InstanceApiToken
 from .instance_api_tokens import InstanceApiTokens
+from .instance_custom_node import InstanceCustomNode
+from .instance_custom_nodes import InstanceCustomNodes
 from .instance_member import InstanceMember
 from .instance_members import InstanceMembers
 from .instance_org import InstanceOrg
@@ -118,7 +123,7 @@ class Client(object):
 
     User API for accessing Losant data
 
-    Built For Version 1.22.0
+    Built For Version 1.23.0
     """
 
     def __init__(self, auth_token=None, url="https://api.losant.com"):
@@ -182,6 +187,8 @@ class Client(object):
         self.instance = Instance(self)
         self.instance_api_token = InstanceApiToken(self)
         self.instance_api_tokens = InstanceApiTokens(self)
+        self.instance_custom_node = InstanceCustomNode(self)
+        self.instance_custom_nodes = InstanceCustomNodes(self)
         self.instance_member = InstanceMember(self)
         self.instance_members = InstanceMembers(self)
         self.instance_org = InstanceOrg(self)
@@ -212,7 +219,7 @@ class Client(object):
             params = {}
 
         headers["Accept"] = "application/json"
-        headers["Accept-Version"] = "^1.22.0"
+        headers["Accept-Version"] = "^1.23.0"
         if self.auth_token:
             headers["Authorization"] = "Bearer {0}".format(self.auth_token)
 
@@ -239,7 +246,7 @@ class Client(object):
             return result
 
         map_data = None
-        if not isinstance(data, collections.Mapping):
+        if not isinstance(data, Mapping):
             map_data = []
             for idx, val in enumerate(data):
                 map_data.append([str(idx), val])
